pub trait Index{
// Required methods
fn ty(&self) -> TypeId;
fn ordinal(&self) -> usize;
fn index_type(&self) -> IndexType;
}Expand description
An Index is a fast lookup mechanism for graph elements.
Indexes allow for efficient querying of graph elements based on different criteria. Each index has a type and can be identified by an ordinal within its type.
Required Methods
Sourcefn ty(&self) -> TypeId
fn ty(&self) -> TypeId
Returns the TypeId of the element being indexed.
Supported types are graph dependent, but all graph implementations support basic Rust types and strings.
Sourcefn ordinal(&self) -> usize
fn ordinal(&self) -> usize
Returns the ordinal number of this index.
The ordinal uniquely identifies an index within its index type.
Sourcefn index_type(&self) -> IndexType
fn index_type(&self) -> IndexType
Returns the type of this index (Hash, Range, or FullText).
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".