pub trait SupportsVertexHashIndex: Graph { }Expand description
Supports indexing of vertices by field using a hash index
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
pub trait SupportsVertexHashIndex: Graph { }Supports indexing of vertices by field using a hash index
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".