pub trait SupportsElementRemoval: Graph {
// Required methods
fn remove_vertex(&mut self, id: Self::VertexId) -> Option<Self::Vertex>;
fn remove_edge(&mut self, id: Self::EdgeId) -> Option<Self::Edge>;
}Expand description
Supports removal of individual vertices and edges
Required Methods
Sourcefn remove_vertex(&mut self, id: Self::VertexId) -> Option<Self::Vertex>
fn remove_vertex(&mut self, id: Self::VertexId) -> Option<Self::Vertex>
Removes a vertex from the graph and returns the vertex.
Sourcefn remove_edge(&mut self, id: Self::EdgeId) -> Option<Self::Edge>
fn remove_edge(&mut self, id: Self::EdgeId) -> Option<Self::Edge>
Removes an edge from the graph and returns the edge.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".